@@ -266,10 +266,10 @@ class Command(BaseCommand):
                         reduce_func = None
 
                         if os.path.exists(map_filename):
-                            map_func = file(map_filename, 'r').read()
+                            map_func = file(map_filename, 'r').read().decode('utf-8')
 
                         if os.path.exists(reduce_filename):
-                            reduce_func = file(reduce_filename, 'r').read()
+                            reduce_func = file(reduce_filename, 'r').read().decode('utf-8')
 
                         if map_func:
                             if not 'views' in doc:
